PokerFace
=========

PokerFace is a Python package for various poker tools.

The following features are present in PokerFace...

- Types for cards and their components and related helper functions
   - Rank
   - Suit
   - Ranks
   - Card
   - Hole Card
- Various types of poker decks
   - Standard Deck
   - Short Deck
- Poker hand evaluations
   - Standard Evaluator
   - Greek Evaluator
   - Omaha Evaluator
   - Short-Deck Evaluator
   - Deuce-to-Seven Lowball Evaluator
   - Ace-to-Five Lowball Evaluator
   - Badugi Evaluator
- Poker game variants
   - Texas Hold'em
      - Fixed-Limit Texas Hold'em
      - No-Limit Texas Hold'em
   - Omaha Hold'em
      - Pot-Limit Omaha Hold'em
   - 5-Card Omaha Hold'em
      - Fixed-Limit 5-Card Omaha Hold'em
      - Pot-Limit 5-Card Omaha Hold'em
   - 6-Card Omaha Hold'em
      - Pot-Limit 6-Card Omaha Hold'em
   - Greek Hold'em
      - Fixed-Limit Greek Hold'em
      - Pot-Limit Greek Hold'em
      - No-Limit Greek Hold'em
   - Short-Deck Hold'em
      - No-Limit Short-Deck Hold'em
   - 5-Card Draw
      - Fixed-Limit 5-Card Draw
      - Pot-Limit 5-Card Draw
      - No-Limit 5-Card Draw
   - Badugi
      - Fixed-Limit Badugi
   - 2-to-7 Single Draw Lowball
      - No-Limit 2-to-7 Single Draw Lowball
   - 2-to-7 Triple Draw Lowball
      - Fixed-Limit 2-to-7 Triple Draw Lowball
      - Pot-Limit 2-to-7 Triple Draw Lowball
   - Kuhn Poker
      - Fixed-Limit Kuhn Poker

The full documentation is available at
`Read the Docs <https://pokerface.readthedocs.io/>`_.

License
-------

`GNU GPLv3 <https://choosealicense.com/licenses/gpl-3.0/>`_
